diff --git a/tests/src/Functional/ExternalLibrary/Definition/DefinitionDiscoveryFactoryTest.php b/tests/src/Functional/ExternalLibrary/Definition/DefinitionDiscoveryFactoryTest.php
index b212bac410e4f804f8496bc14286e2d425d87a15..71ba6f1da2aeccebcc93491381aa3a1e036da92c 100644
--- a/tests/src/Functional/ExternalLibrary/Definition/DefinitionDiscoveryFactoryTest.php
+++ b/tests/src/Functional/ExternalLibrary/Definition/DefinitionDiscoveryFactoryTest.php
@@ -30,11 +30,11 @@ class DefinitionDiscoveryFactoryTest extends BrowserTestBase {
   protected $definitionPath;
 
   /**
    * Set default theme to stable.
    *
    * @var string
    */
-  protected $defaultTheme = 'stable';
+  protected $defaultTheme = 'stark';
 
   /**
    * {@inheritdoc}
@@ -30,11 +30,11 @@ class DefinitionDiscoveryFactoryTest extends BrowserTestBase {
 
   /**
-   * Set default theme to stable.
+   * Set default theme to stark.
    *
    * @var string
diff --git a/tests/src/Functional/LibrariesWebTest.php b/tests/src/Functional/LibrariesWebTest.php
index d1c964a39bdc50cdac0f2ee9214ab65b00eda2de..9fdc9f6c8df8ff4ad44767ef4f3670e97ae740e8 100644
--- a/tests/src/Functional/LibrariesWebTest.php
+++ b/tests/src/Functional/LibrariesWebTest.php
@@ -18,11 +18,11 @@ class LibrariesWebTest extends BrowserTestBase {
   protected $profile = 'testing';
 
   /**
    * Set default theme to stable.
    *
    * @var string
    */
-  protected $defaultTheme = 'stable';
+  protected $defaultTheme = 'stark';
 
   /**
    * Modules to install.
@@ -18,11 +18,11 @@ class LibrariesWebTest extends BrowserTestBase {
 
   /**
-   * Set default theme to stable.
+   * Set default theme to stark.
    *
    * @var string